@@ -19,7 +19,9 @@ namespace Tasque
 		private static Gdk.Pixbuf[] inactiveAnimPixbufs;
 		
 		private Gtk.TreeModelFilter modelFilter;
-		private ICategory filterCategory;
+		private ICategory filterCategory;		
+
+		private static string status;
 		
 		static TaskTreeView ()
 		{
@@ -36,7 +38,17 @@ namespace Tasque
 
 		public TaskTreeView (Gtk.TreeModel model)
 			: base ()
-		{
+		{		
+
+			#if GTK_2_12
+			// set up the timing for the tooltips
+			this.Settings.SetLongProperty("gtk-tooltip-browse-mode-timeout", 0, "Tasque:TaskTreeView");
+			this.Settings.SetLongProperty("gtk-tooltip-browse-timeout", 750, "Tasque:TaskTreeView");
+			this.Settings.SetLongProperty("gtk-tooltip-timeout", 750, "Tasque:TaskTreeView");
+
+			ConnectEvents();
+			#endif
+			
 			// TODO: Modify the behavior of the TreeView so that it doesn't show
 			// the highlighted row.  Then, also tie in with the mouse hovering
 			// so that as you hover the mouse around, it will automatically
@@ -255,7 +267,6 @@ namespace Tasque
 		#endregion // Public Methods
 		
 		#region Private Methods
-		
 		protected override void OnRealized ()
 		{
 			base.OnRealized ();
@@ -265,11 +276,16 @@ namespace Tasque
 			Refilter (filterCategory);
 		}
 
+		private static void ShowCompletedTaskStatus ()
+		{
+			status = Catalog.GetString ("Task Completed");
+			TaskWindow.ShowStatus (status);
+		}
 		
 		private void TaskToggleCellDataFunc (Gtk.TreeViewColumn column,
-											 Gtk.CellRenderer cell,
-											 Gtk.TreeModel model,
-											 Gtk.TreeIter iter)
+										Gtk.CellRenderer cell,
+										Gtk.TreeModel model,
+										Gtk.TreeIter iter)
 		{
 			Gtk.CellRendererToggle crt = cell as Gtk.CellRendererToggle;
 			ITask task = model.GetValue (iter, 0) as ITask;
@@ -281,6 +297,56 @@ namespace Tasque
 			}
 		}
 
+		#if GTK_2_12
+		private void ConnectEvents()
+		{
+			this.CursorChanged += delegate(object o, EventArgs args) {			
+			int toolTipMaxLength = 250;
+			string snipText = "...";
+			int maxNumNotes = 3;
+			int notesAdded = 0;
+			TooltipText = null;
+			TriggerTooltipQuery();
+			TreeModel m;
+			TreeIter iter;
+			List<String> list = new List<String>();
+	
+			if(Selection.GetSelected(out m, out iter)) {
+				ITask task = Model.GetValue (iter, 0) as ITask;							      
+				if (task != null && task.HasNotes && task.Notes != null) {
+					foreach (INote note in task.Notes) {
+						// for the tooltip, truncate any notes longer than 250 characters.
+						if (note.Text.Length > toolTipMaxLength)
+							list.Add(note.Text.Substring(0, toolTipMaxLength - snipText.Length) + 
+											snipText);
+						else
+							list.Add(note.Text);
+						notesAdded++;
+						// stop iterating once we reach maxNumNotes
+						if (notesAdded >= maxNumNotes) {
+							break;
+						}
+					}
+				}			      		
+		
+				HasTooltip = list.Count > 0;
+				if (HasTooltip) {
+					// if there are more than maxNumNotes, append a notice to the tooltip
+					if (notesAdded < task.Notes.Count) {
+						int nMoreNotes = task.Notes.Count - notesAdded;
+						if (nMoreNotes > 1)
+							list.Add(String.Format("[{0} more notes]", nMoreNotes));
+						else
+							list.Add("[1 more note]");
+					}
+					TooltipText = String.Join("\n\n", list.ToArray());
+					TriggerTooltipQuery();
+				}
+			}
+			};
+		}
+		#endif
+
 		void TaskPriorityCellDataFunc (Gtk.TreeViewColumn tree_column,
 									   Gtk.CellRenderer cell,
 									   Gtk.TreeModel tree_model,
@@ -454,6 +520,11 @@ namespace Tasque
 		{
 			// Filter out deleted tasks
 			ITask task = model.GetValue (iter, 0) as ITask;
+
+			if (task == null) {
+				Logger.Error ("FilterFunc: task at iter was null");
+				return false;
+			}
 			
 			if (task.State == TaskState.Deleted) {
 				//Logger.Debug ("TaskTreeView.FilterFunc:\n\t{0}\n\t{1}\n\tReturning false", task.Name, task.State);  
@@ -473,7 +544,7 @@ namespace Tasque
 			Logger.Debug ("OnTaskToggled");
 			Gtk.TreeIter iter;
 			Gtk.TreePath path = new Gtk.TreePath (args.Path);
-			if (Model.GetIter (out iter, path) == false)
+			if (!Model.GetIter (out iter, path))
 				return; // Do nothing
 			
 			ITask task = Model.GetValue (iter, 0) as ITask;
@@ -491,8 +562,9 @@ namespace Tasque
 				// When showCompletedTasks is true, complete the tasks right
 				// away.  Otherwise, set a timer and show the timer animation
 				// before marking the task completed.
-				if (showCompletedTasks == true) {
+				if (showCompletedTasks) {
 					task.Complete ();
+					ShowCompletedTaskStatus ();
 				} else {
 					task.Inactivate ();
 					
@@ -505,6 +577,8 @@ namespace Tasque
 					timer.StartTimer ();
 				}
 			} else {
+				status = Catalog.GetString ("Action Canceled");
+				TaskWindow.ShowStatus (status);
 				task.Activate ();
 			}
 		}
@@ -513,7 +587,7 @@ namespace Tasque
 		{
 			Gtk.TreeIter iter;
 			Gtk.TreePath path = new TreePath (args.Path);
-			if (Model.GetIter (out iter, path) == false)
+			if (!Model.GetIter (out iter, path))
 				return;
 
 			TaskPriority newPriority;
@@ -536,7 +610,7 @@ namespace Tasque
 		{
 			Gtk.TreeIter iter;
 			Gtk.TreePath path = new TreePath (args.Path);
-			if (Model.GetIter (out iter, path) == false)
+			if (!Model.GetIter (out iter, path))
 				return;
 			
 			ITask task = Model.GetValue (iter, 0) as ITask;
@@ -581,7 +655,7 @@ namespace Tasque
 			
 			Gtk.TreeIter iter;
 			Gtk.TreePath path = new TreePath (args.Path);
-			if (Model.GetIter (out iter, path) == false)
+			if (!Model.GetIter (out iter, path))
 				return;
 			
 			//  2/11 - Today
@@ -675,7 +749,9 @@ namespace Tasque
 			private TaskTreeView tree;
 			private ITask task;
 			private uint delay;
+			private uint secondsLeft;
 			protected uint pulseTimeoutId;
+			private uint secondTimerId;
 			private Gtk.TreeIter iter;
 			private Gtk.TreePath path;
 			
@@ -688,6 +764,7 @@ namespace Tasque
 				iter = taskIter;
 				path = treeView.Model.GetPath (iter);
 				task = taskToComplete;
+				secondsLeft = delayInSeconds;
 				delay = delayInSeconds * 1000; // Convert to milliseconds
 				pulseTimeoutId = 0;
 			}
@@ -695,13 +772,14 @@ namespace Tasque
 			public void StartTimer ()
 			{
 				pulseTimeoutId = GLib.Timeout.Add (500, PulseAnimation);
+				StartSecondCountdown ();
 				task.TimerID = GLib.Timeout.Add (delay, CompleteTask);
 				timers [task.TimerID] = this;
 			}
-			
+		
 			public static void CancelTimer(ITask task)
 			{
-				Logger.Debug("Timeout Canceled for task: " + task.Name);
+				Logger.Debug ("Timeout Canceled for task: " + task.Name);
 				InactivateTimer timer = null;
 				uint timerId = task.TimerID;
 				if(timerId != 0) {
@@ -729,6 +807,7 @@ namespace Tasque
 					return false;
 					
 				task.Complete ();
+				ShowCompletedTaskStatus ();
 				tree.Refilter ();
 				return false; // Don't automatically call this handler again
 			}
@@ -749,6 +828,28 @@ namespace Tasque
 					return true;
 				}
 			}
+
+			private void StartSecondCountdown ()
+			{
+				SecondCountdown();
+				secondTimerId = GLib.Timeout.Add (1000, SecondCountdown);
+			}
+
+			private bool SecondCountdown ()
+			{
+				if (tree.Model == null) {
+					// Widget has been closed, no need to call this again
+					return false;
+				}
+				if (secondsLeft > 0 && task.State == TaskState.Inactive) {
+					status = String.Format (Catalog.GetString ("Completing Task In: {0}"), secondsLeft--);
+					TaskWindow.ShowStatus (status);
+					return true;
+				} else {
+					return false;
+				}
+			}
+	
 		}
 		#endregion // Private Classes
 	}
