@@ -30,6 +30,7 @@
 
 using System;
 using System.Collections.Generic;
+using Gdk;
 using Gtk;
 using Mono.Unix;
 
@@ -58,7 +59,8 @@ namespace Tasque
 		private TaskGroup nextSevenDaysGroup;
 		private TaskGroup futureGroup;
 		private CompletedTaskGroup completedTaskGroup;
-		
+		private EventBox innerEb;
+
 		private List<TaskGroup> taskGroups;
 		
 		private Dictionary<ITask, NoteDialog> noteDialogs;
@@ -66,6 +68,10 @@ namespace Tasque
 		private Gtk.Statusbar statusbar;
 		private uint statusContext;
 		private uint currentStatusMessageId;
+		private static uint ShowOriginalStatusId;
+		private static string status;
+		private static string lastLoadedTime;
+		private const uint DWELL_TIME_MS = 8000;
 		
 		private ITask clickedTask;
 		
@@ -77,7 +83,7 @@ namespace Tasque
 			noteIcon = Utilities.GetIcon ("note", 16);
 		}
 		
-		public TaskWindow (IBackend aBackend) : base (WindowType.Toplevel)
+		public TaskWindow (IBackend aBackend) : base (Gtk.WindowType.Toplevel)
 		{
 			this.backend = aBackend;
 			taskGroups = new List<TaskGroup> ();
@@ -110,19 +116,10 @@ namespace Tasque
 			AddAccelGroup (accelGroup);
 			globalKeys = new GlobalKeybinder (accelGroup);
 
-			// Start with an event box to paint the background white
-			EventBox eb = new EventBox();
-			eb.BorderWidth = 0;
-			eb.ModifyBg(	StateType.Normal, 
-					new Gdk.Color(255,255,255));
-			eb.ModifyBase(	StateType.Normal, 
-					new Gdk.Color(255,255,255));
-			
 			VBox mainVBox = new VBox();
 			mainVBox.BorderWidth = 0;
 			mainVBox.Show ();
-			eb.Add(mainVBox);
-			this.Add (eb);
+			this.Add (mainVBox);
 			
 			HBox topHBox = new HBox (false, 0);
 			topHBox.BorderWidth = 4;
@@ -161,7 +158,7 @@ namespace Tasque
 			
 			// Use a small add icon so the button isn't mammoth-sized
 			HBox buttonHBox = new HBox (false, 6);
-			Image addImage = new Image (Gtk.Stock.Add, IconSize.Menu);
+			Gtk.Image addImage = new Gtk.Image (Gtk.Stock.Add, IconSize.Menu);
 			addImage.Show ();
 			buttonHBox.PackStart (addImage, false, false, 0);
 			Label l = new Label (Catalog.GetString ("_Add"));
@@ -171,7 +168,7 @@ namespace Tasque
 			addTaskButton = 
 				new MenuToolButton (buttonHBox, Catalog.GetString ("_Add Task"));
 			addTaskButton.UseUnderline = true;
-		    	// Disactivate the button until the backend is initialized
+			// Disactivate the button until the backend is initialized
 			addTaskButton.Sensitive = false;
 			Gtk.Menu addTaskMenu = new Gtk.Menu ();
 			addTaskButton.Menu = addTaskMenu;
@@ -180,15 +177,15 @@ namespace Tasque
 			topHBox.PackStart (addTaskButton, false, false, 0);
 			
 			globalKeys.AddAccelerator (OnGrabEntryFocus,
-			                           (uint) Gdk.Key.n,
-			                           Gdk.ModifierType.ControlMask,
-			                           Gtk.AccelFlags.Visible);
+						(uint) Gdk.Key.n,
+						Gdk.ModifierType.ControlMask,
+						Gtk.AccelFlags.Visible);
 			
 			globalKeys.AddAccelerator (delegate (object sender, EventArgs e) {
 				Application.Instance.Quit (); },
-			                           (uint) Gdk.Key.q,
-			                           Gdk.ModifierType.ControlMask,
-			                           Gtk.AccelFlags.Visible);
+						(uint) Gdk.Key.q,
+						Gdk.ModifierType.ControlMask,
+						Gtk.AccelFlags.Visible);
 			
 			topHBox.Show ();
 			mainVBox.PackStart (topHBox, false, false, 0);
@@ -202,13 +199,12 @@ namespace Tasque
 			scrolledWindow.Show ();
 			mainVBox.PackStart (scrolledWindow, true, true, 0);
 
-			EventBox innerEb = new EventBox();
+			innerEb = new EventBox();
 			innerEb.BorderWidth = 0;
-			innerEb.ModifyBg(	StateType.Normal, 
-						new Gdk.Color(255,255,255));
-			innerEb.ModifyBase(	StateType.Normal, 
-						new Gdk.Color(255,255,255));
-
+			Gdk.Color backgroundColor = GetBackgroundColor ();
+			innerEb.ModifyBg (StateType.Normal, backgroundColor);
+			innerEb.ModifyBase (StateType.Normal, backgroundColor);
+			
 			targetVBox = new VBox();
 			targetVBox.BorderWidth = 5;
 			targetVBox.Show ();
@@ -243,8 +239,6 @@ namespace Tasque
 
 		void PopulateWindow()
 		{
-			
-
 			// Add in the groups
 			
 			//
@@ -406,10 +400,20 @@ namespace Tasque
 
 		}
 		
-		public static void ShowWindow()
+		public static void ShowWindow ()
+		{
+			ShowWindow (false);
+		}
+		
+		public static void ToggleWindowVisible ()
+		{
+			ShowWindow (true);
+		}
+		
+		private static void ShowWindow(bool supportToggle)
 		{
 			if(taskWindow != null) {
-				if(taskWindow.IsActive) {
+				if(taskWindow.IsActive && supportToggle) {
 					int x;
 					int y;
 
@@ -429,11 +433,7 @@ namespace Tasque
 					}
 					taskWindow.Present();
 				}
-			} else {
-				// TODO: Eventually move the creation of the IBackend into
-				// something that will parse the command line to read which
-				// backend should be used.  If no specific backend is specified,
-				// use RtmTaskBackend by default.
+			} else if (Application.Backend != null) {
 				TaskWindow.taskWindow = new TaskWindow(Application.Backend);
 				if(lastXPos == 0 || lastYPos == 0)
 				{
@@ -465,24 +465,44 @@ namespace Tasque
 			taskWindow.EnterEditMode (task, true);
 			taskWindow.Present ();
 		}
+
+		public static bool ShowOriginalStatus ()
+		{
+			status = string.Format ("Tasks loaded: {0}", TaskWindow.lastLoadedTime);
+			TaskWindow.ShowStatus (status);
+			return false;
+		}
 		
 		public static void ShowStatus (string statusText)
+		{
+			// By default show the new status for 8 seconds
+			ShowStatus (statusText, DWELL_TIME_MS);
+		}
+
+		public static void ShowStatus (string statusText, uint dwellTime)
 		{
 			if (taskWindow == null) {
 				Logger.Warn ("Cannot set status when taskWindow is null");
 				return;
 			}
+
+			// remove old timer to show original status and then start another one
+			if (ShowOriginalStatusId > 0)
+				GLib.Source.Remove (ShowOriginalStatusId);
+			// any status will dwell for <dwellTime> seconds and then the original
+			//status will be shown
+			ShowOriginalStatusId = GLib.Timeout.Add (dwellTime, ShowOriginalStatus);
 			
 			if (taskWindow.currentStatusMessageId != 0) {
 				// Pop the old message
 				taskWindow.statusbar.Remove (taskWindow.statusContext,
-											 taskWindow.currentStatusMessageId);
+								taskWindow.currentStatusMessageId);
 				taskWindow.currentStatusMessageId = 0;
 			}
 			
 			taskWindow.currentStatusMessageId =
 				taskWindow.statusbar.Push (taskWindow.statusContext,
-										   statusText);
+								statusText);
 		}
 
 		public static bool IsOpen
@@ -495,15 +515,16 @@ namespace Tasque
 		/// <summary>
 		/// This should be called after a new IBackend has been set
 		/// </summary>
-		public static void Reinitialize ()
+		public static void Reinitialize (bool show)
 		{
 			if (TaskWindow.taskWindow != null) {
 				TaskWindow.taskWindow.Hide ();
 				TaskWindow.taskWindow.Destroy ();
 				TaskWindow.taskWindow = null;
 			}
-			
-			TaskWindow.ShowWindow ();
+
+			if (show)
+				TaskWindow.ShowWindow ();
 		}
 		
 		public void HighlightTask (ITask task)
@@ -519,7 +540,7 @@ namespace Tasque
 				Gtk.Application.RunIteration ();
 
 			foreach (TaskGroup taskGroup in taskGroups) {
-				if (taskGroup.ContainsTask (task, out iter) == true) {
+				if (taskGroup.ContainsTask (task, out iter)) {
 					taskGroup.TreeView.Selection.SelectIter (iter);
 					break;
 				}
@@ -563,7 +584,7 @@ namespace Tasque
 				//Logger.Debug("taskGroupHeights: {0}", taskGroupHeights);
 				TreePath start;
 				TreePath end;
-				if (taskGroup.TreeView.GetVisibleRange (out start, out end) == true) {
+				if (taskGroup.TreeView.GetVisibleRange (out start, out end)) {
 					Logger.Debug ("TaskGroup '{0}' range: {1} - {2}",
 						taskGroup.DisplayName,
 						start.ToString (),
@@ -572,7 +593,7 @@ namespace Tasque
 					Logger.Debug ("TaskGroup range not visible: {0}", taskGroup.DisplayName);
 				}
 				
-				if (taskGroup.ContainsTask (task, out iter) == true) {
+				if (taskGroup.ContainsTask (task, out iter)) {
 					Logger.Debug ("Found new task group: {0}", taskGroup.DisplayName);
 					
 					// Get the header height
@@ -634,7 +655,7 @@ namespace Tasque
 			Gtk.TreeIter iter;
 			Gtk.TreeModel model = Application.Backend.Tasks;
 			
-			if (model.GetIterFirst (out iter) == false)
+			if (!model.GetIterFirst (out iter))
 				return 0;
 			
 			do {
@@ -647,7 +668,7 @@ namespace Tasque
 				
 				if (category.ContainsTask (task))
 					count++;
-			} while (model.IterNext (ref iter) == true);
+			} while (model.IterNext (ref iter));
 			
 			return count;
 		}
@@ -675,13 +696,13 @@ namespace Tasque
 			while (Gtk.Application.EventsPending ())
 				Gtk.Application.RunIteration ();
 			
-			if (adjustScrolledWindow == true)
+			if (adjustScrolledWindow)
 				ScrollToTask (task);
 			
 			
 			Gtk.TreeIter iter;
 			foreach (TaskGroup taskGroup in taskGroups) {
-				if (taskGroup.ContainsTask (task, out iter) == true) {
+				if (taskGroup.ContainsTask (task, out iter)) {
 					Logger.Debug ("Found new task group: {0}", taskGroup.DisplayName);
 					
 					// Get the header height
@@ -696,7 +717,7 @@ namespace Tasque
 			Gtk.Menu menu = new Menu ();
 			
 			Gtk.TreeIter iter;
-			if (categoriesModel.GetIterFirst (out iter) == true) {
+			if (categoriesModel.GetIterFirst (out iter)) {
 				do {
 					ICategory category =
 						categoriesModel.GetValue (iter, 0) as ICategory;
@@ -708,7 +729,7 @@ namespace Tasque
 					item.Activated += OnNewTaskByCategory;
 					item.ShowAll ();
 					menu.Add (item);
-				} while (categoriesModel.IterNext (ref iter) == true);
+				} while (categoriesModel.IterNext (ref iter));
 			}
 			
 			addTaskButton.Menu = menu;
@@ -723,7 +744,7 @@ namespace Tasque
 			if (categoryName != null) {
 				// Iterate through (yeah, I know this is gross!) and find the
 				// matching category
-				if (model.GetIterFirst (out iter) == true) {
+				if (model.GetIterFirst (out iter)) {
 					do {
 						ICategory cat = model.GetValue (iter, 0) as ICategory;
 						if (cat == null)
@@ -733,14 +754,14 @@ namespace Tasque
 							categoryWasSelected = true;
 							break;
 						}
-					} while (model.IterNext (ref iter) == true);
+					} while (model.IterNext (ref iter));
 				}
 			}
 			
-			if (categoryWasSelected == false) {
+			if (!categoryWasSelected) {
 				// Select the first item in the list (which should be the "All"
 				// category.
-				if (model.GetIterFirst (out iter) == true) {
+				if (model.GetIterFirst (out iter)) {
 					// Make sure we can actually get a category
 					ICategory cat = model.GetValue (iter, 0) as ICategory;
 					if (cat != null)
@@ -752,7 +773,7 @@ namespace Tasque
 		private void ShowTaskNotes (ITask task)
 		{
 			NoteDialog dialog = null;
-			if (noteDialogs.ContainsKey (task) == false) {
+			if (!noteDialogs.ContainsKey (task)) {
 				dialog = new NoteDialog (this, task);
 				dialog.Hidden += OnNoteDialogHidden;
 				noteDialogs [task] = dialog;
@@ -771,9 +792,14 @@ namespace Tasque
 			ITask task = backend.CreateTask (taskText, category);
 			
 			if (task == null) {
-				// TODO: Change the status to say there was an error
 				Logger.Debug ("Error creating a new task!");
+				// Show error status
+				status = Catalog.GetString ("Error creating a new task");
+				TaskWindow.ShowStatus (status);
 			} else {
+				// Show successful status
+				status = Catalog.GetString ("Task created successfully");	
+				TaskWindow.ShowStatus (status);
 				// Clear out the entry
 				addTaskEntry.Text = string.Empty;
 				addTaskEntry.GrabFocus ();
@@ -781,9 +807,37 @@ namespace Tasque
 			
 			return task;
 		}
+		
+		/// <summary>
+		/// This returns the current input widget color from the GTK theme
+		/// </summary>
+		/// <returns>
+		/// A Gdk.Color
+		/// </returns>
+		private Gdk.Color GetBackgroundColor ()
+		{
+			using (Gtk.Style style = Gtk.Rc.GetStyle (this)) 
+				return style.Base (StateType.Normal);
+		}
+		
 		#endregion // Private Methods
 
 		#region Event Handlers
+		protected override void OnStyleSet (Gtk.Style previous_style)
+		{
+			base.OnStyleSet (previous_style);
+			Gdk.Color backgroundColor = GetBackgroundColor ();
+			innerEb.ModifyBg (StateType.Normal, backgroundColor);
+			innerEb.ModifyBase (StateType.Normal, backgroundColor);
+			
+			if (addTaskEntry.Text == Catalog.GetString ("New task...")) {
+				Gdk.Color insensitiveColor =
+					addTaskEntry.Style.Text (Gtk.StateType.Insensitive);
+				addTaskEntry.ModifyText (Gtk.StateType.Normal, insensitiveColor);
+			}
+
+		}
+		
 		private void OnRealized (object sender, EventArgs args)
 		{
 			addTaskEntry.GrabFocus ();
@@ -876,7 +930,7 @@ namespace Tasque
 				return;
 			
 			Gtk.TreeIter iter;
-			if (categoryComboBox.GetActiveIter (out iter) == false)
+			if (!categoryComboBox.GetActiveIter (out iter))
 				return;
 			
 			ICategory category =
@@ -920,7 +974,7 @@ namespace Tasque
 			// to switch the category first so the user will be able to edit
 			// the title of the task.
 			Gtk.TreeIter iter;
-			if (categoryComboBox.GetActiveIter (out iter) == true) {
+			if (categoryComboBox.GetActiveIter (out iter)) {
 				ICategory selectedCategory =
 					categoryComboBox.Model.GetValue (iter, 0) as ICategory;
 				
@@ -948,7 +1002,7 @@ namespace Tasque
 		void OnCategoryChanged (object sender, EventArgs args)
 		{
 			Gtk.TreeIter iter;
-			if (categoryComboBox.GetActiveIter (out iter) == false)
+			if (!categoryComboBox.GetActiveIter (out iter))
 				return;
 			
 			ICategory category =
@@ -979,7 +1033,7 @@ namespace Tasque
 			
 			Gtk.TreeIter iter;
 			
-			if (model.GetIter (out iter, args.Path) == false)
+			if (!model.GetIter (out iter, args.Path))
 				return;
 			
 			ITask task = model.GetValue (iter, 0) as ITask;
@@ -1007,11 +1061,11 @@ namespace Tasque
 					Gtk.TreePath path;
 					Gtk.TreeViewColumn column = null;
 
-					if (tv.GetPathAtPos ((int) args.Event.X,
-									(int) args.Event.Y, out path, out column) == false)
+					if (!tv.GetPathAtPos ((int) args.Event.X,
+									(int) args.Event.Y, out path, out column))
 						return;
 
-					if (model.GetIter (out iter, path) == false)
+					if (!model.GetIter (out iter, path))
 						return;
 					
 					clickedTask = model.GetValue (iter, 0) as ITask;
@@ -1022,19 +1076,19 @@ namespace Tasque
 					ImageMenuItem item;
 					
 					item = new ImageMenuItem (Catalog.GetString ("_Notes..."));
-					item.Image = new Image (noteIcon);
+					item.Image = new Gtk.Image (noteIcon);
 					item.Activated += OnShowTaskNotes;
 					popupMenu.Add (item);
 					
 					popupMenu.Add (new SeparatorMenuItem ());
 
 					item = new ImageMenuItem (Catalog.GetString ("_Delete task"));
-					item.Image = new Image(Gtk.Stock.Delete, IconSize.Menu);
+					item.Image = new Gtk.Image(Gtk.Stock.Delete, IconSize.Menu);
 					item.Activated += OnDeleteTask;
 					popupMenu.Add (item);
 
 					item = new ImageMenuItem(Catalog.GetString ("_Edit task"));
-					item.Image = new Image(Gtk.Stock.Edit, IconSize.Menu);
+					item.Image = new Gtk.Image(Gtk.Stock.Edit, IconSize.Menu);
 					item.Activated += OnEditTask;
 					popupMenu.Add (item);
 
@@ -1058,8 +1112,11 @@ namespace Tasque
 		{
 			if (clickedTask == null)
 				return;
-			
+		
 			Application.Backend.DeleteTask(clickedTask);
+			
+			status = Catalog.GetString ("Task deleted");
+			TaskWindow.ShowStatus (status);
 		}
 
 
@@ -1080,7 +1137,7 @@ namespace Tasque
 				return;
 			}
 			
-			if (noteDialogs.ContainsKey (dialog.Task) == false) {
+			if (!noteDialogs.ContainsKey (dialog.Task)) {
 				Logger.Warn ("Closed NoteDialog not found in noteDialogs");
 				return;
 			}
@@ -1107,8 +1164,9 @@ namespace Tasque
 		{
 			Logger.Debug("Backend sync finished");
 			if (Application.Backend.Configured) {
-				string status =
-					string.Format ("Tasks loaded: {0}",DateTime.Now.ToString ());
+				string now = DateTime.Now.ToString ();
+				status = string.Format ("Tasks loaded: {0}", now);
+				TaskWindow.lastLoadedTime = now;
 				TaskWindow.ShowStatus (status);
 				RebuildAddTaskMenu (Application.Backend.Categories);
 				addTaskEntry.Sensitive = true;
